#
# spec file for package perl-MCE
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name MCE
Name:           perl-MCE
Version:        1.876
Release:        bp154.1.22
Summary:        Many-Core Engine for Perl providing parallel processing capabilities
License:        Artistic-1.0 OR GPL-1.0-or-later
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/M/MA/MARIOROY/%{cpan_name}-%{version}.tar.gz
Source1:        cpanspec.yml
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.88
Recommends:     perl(Sereal::Decoder) >= 3.015
Recommends:     perl(Sereal::Encoder) >= 3.015
%{perl_requires}

%description
MCE spawns a pool of workers and therefore does not fork a new process per
each element of data. Instead, MCE follows a bank queuing model. Imagine
the line being the data and bank-tellers the parallel workers. MCE enhances
that model by adding the ability to chunk the next n elements from the
input stream to the next available worker.

%prep
%autosetup  -n %{cpan_name}-%{version}

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes Credits README.md
%license Copying LICENSE

%changelog
* Fri Dec  3 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.876
  see /usr/share/doc/packages/perl-MCE/Changes
  1.876 Thu Dec 02 18:00:00 EST 2021
  * Allow percentage above 100%% for max_workers in MCE.
  * MCE::Child update.
    Improved _ordhash.
    Renamed JOINED to REAPED in code for better clarity.
    Specify a percentage for max_workers.
    Added t/05_mce_child_max_workers.t
* Wed Nov 17 2021 Tina Müller <timueller+perl@suse.de>
- updated to 1.875
  see /usr/share/doc/packages/perl-MCE/Changes
  1.875 Tue Nov 16 04:00:00 EST 2021
  * Specify a percentage for max_workers.
    Thank you, kcott@PerlMonks (Ken) for the idea.
    https://www.perlmonks.org/?node_id=11134439
  * Added t/03_max_workers.t
* Wed Aug 19 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.874
  see /usr/share/doc/packages/perl-MCE/Changes
* Sun Aug  2 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.873
  see /usr/share/doc/packages/perl-MCE/Changes
  1.873 Sat Aut 01 16:00:00 EST 2020
  * Removed unused variable in MCE::Mutex::Channel.
  * Fixed typo in prior change log.
    Replaced "completed" with "feature complete".
* Tue Jun 16 2020 Tina Müller <timueller+perl@suse.de>
- updated to 1.872
  see /usr/share/doc/packages/perl-MCE/Changes
  1.872 Sun Jun 14 22:30:00 EST 2020
  * Added open to required dependencies.
  * Set default encodings on standard filehandles in tests using UTF-8.
  * Bumped minimal Perl version to 5.8.1.
  * Bumped MCE version to 1.872 to align with MCE::Shared.
  * The MCE project is completed.
* Tue May 12 2020 Tina Müller <timueller+perl@suse.de>
  updated to 1.868
  see /usr/share/doc/packages/perl-MCE/Changes
  1.868 Sun May 10 22:00:00 EST 2020
  * Completed threads-like detach capability in MCE::Child.
  * Resolved MCE::Channel failing when calling dequeue multiple times
    on an ended channel.
  * MCE->say, MCE->print, and MCE->printf now return 1.
  1.867 Sun May 03 18:00:00 EST 2020
  * Bug fix for UTF-8 issues during inter-process communication.
    This update required undoing optimizations specific to scalar args.
    Essentially, IPC involves serialization for everything going forward.
    Install Sereal::Encoder and Sereal::Decoder for better performance
    in Perl 5.8.8+.
  * MCE options flush_stdout, flush_stderr, and flush_file now default to
    enabled for the MCE->print, MCE->printf, and MCE->say output routines.
  * Improved MCE::Child with threads-like detach capability. See POD.
  * Improved IPC in MCE::Queue with permanent fast-like dequeue including
    dequeue_nb. Going forward, the fast and barrier options are silently
    ignored if specified (i.e. no-op).
  * Improved IPC performance on Linux.
* Mon Feb 10 2020 <timueller+perl@suse.de>
- updated to 1.866
  see /usr/share/doc/packages/perl-MCE/Changes
  1.866 Sat Feb 08 21:00:00 EST 2020
  * Bug fix for restart_worker, race condition introduced in 1.863.
    Thank you, Oliver Gorwits for reporting the issue.
* Thu Dec 26 2019 <timueller+perl@suse.de>
- updated to 1.865
  see /usr/share/doc/packages/perl-MCE/Changes
  1.865 Wed Dec 25 18:00:00 EST 2019
  * Bug fix for two-way IPC stalling on Windows in MCE::Channel::Threads.
    See https://www.perlmonks.org/?node_id=11110612
  * Remove the check for MSWin32 in MCE::Channel::Mutex. MCE::Channel since
    the 1st release silently defaults to MCE::Channel::Threads on Windows.
  * Small tweak to MCE::Signal.
* Thu Dec  5 2019 <timueller+perl@suse.de>
- updated to 1.864
  see /usr/share/doc/packages/perl-MCE/Changes
  1.864 Wed Dec 04 13:00:00 EST 2019
  * Bug fix to MCE::Signal - Shared manager not exiting, introduced in 1.863.
  * Use monotonic clock if available in MCE->yield and MCE::Child->yield.
* Mon Nov 25 2019 <timueller+perl@suse.de>
- updated to 1.863
  see /usr/share/doc/packages/perl-MCE/Changes
  1.863 Sun Nov 26 20:00:00 EST 2019
  * On Cygwin, silently use Mutex in MCE::Channel when Threads is specified
    for better performance.
  * New defer capability in MCE::Signal. This applies to MCE::Shared 1.863.
    See POD section labled "DEFER SIGNAL" in MCE::Signal.
  * Reverted $child->exit back to sending the SIGQUIT signal in MCE::Child
    now that MCE::Shared::Server 1.863 defers signal during IPC.
  * Improved reliability for spawning MCE and MCE::Child inside threads
    including nested parallelization, made possible using a global lock
    $MCE::_GMUTEX.
  * Updated signal handling in mce-examples/framebuffer on GitHub.
* Fri Sep 20 2019 <timueller+perl@suse.de>
- updated to 1.862
  see /usr/share/doc/packages/perl-MCE/Changes
  1.862 Wed Sep 18 22:00:00 EST 2019
  * Hotfix for 1.861.
* Thu Sep 19 2019 <timueller+perl@suse.de>
- updated to 1.861
  see /usr/share/doc/packages/perl-MCE/Changes
  1.861 Wed Sep 18 08:30:00 EST 2019
  * Hotfix for 1.849-1.860. The edge cases regarding signal handling have
    been finally resolved for MCE::Child. Thank you, Richard Kelsch for the
    use case involving ctrl-c. See mce-examples/framebuffer on GitHub.
* Mon Sep 16 2019 <timueller+perl@suse.de>
- updated to 1.860
  see /usr/share/doc/packages/perl-MCE/Changes
  1.860 Sun Sep 15 20:00:00 EST 2019
  * Signal-handling update release.
  * Localized input and output record separators in MCE::Channel.
  * IPC safety in MCE::Child during SIGINT and SIGTERM.
  * Method $child->exit in MCE::Child now sends the SIGINT signal
    for extra reliability with MCE::Shared (previously SIGQUIT).
* Tue Sep 10 2019 <timueller+perl@suse.de>
- updated to 1.850
  see /usr/share/doc/packages/perl-MCE/Changes
  1.850 Mon Sep 09 12:30:00 EST 2019
  * Bumped version to coincide with the stable MCE::Shared 1.850 release.
  1.849 Sun Sep 08 23:30:00 EST 2019
  * Fixed edge case in MCE::Child when reaping inside a signal handler.
  * Added list_pids class method to MCE::Child.
* Thu Sep  5 2019 <timueller+perl@suse.de>
- updated to 1.848
  see /usr/share/doc/packages/perl-MCE/Changes
  1.848 Tue Sep 03 23:30:00 EST 2019
  * Improved IO::All::{ File, Pipe, STDIO } output via MCE->print($io, ...),
    printf, and say. This resolves a bug introduced in 1.845 when using
    App::Cmd::Tester to capture output.
* Wed Sep  4 2019 <timueller+perl@suse.de>
- updated to 1.847
  see /usr/share/doc/packages/perl-MCE/Changes
  1.847 Mon Sep 02 23:30:00 EST 2019
  * Obsolete RedHat MCE-1.840-Sereal-deps.patch file. This patch file
    is no longer needed and finally resolved with this release.
  * PDL random numbers now unique between threads. Thank you, PerlMonks (vr).
    See https://www.perlmonks.org/?node_id=1214439.
  * Replaced "PF_UNIX" with "AF_UNIX" in MCE::Util.
* Tue Aug 27 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.846
  see /usr/share/doc/packages/perl-MCE/Changes
  1.846 Mon Aug 26 21:30:00 EST 2019
  * Fixed code tags in documentation. Thank you, Mohammad S Anwar.
* Mon Aug 26 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.845
  see /usr/share/doc/packages/perl-MCE/Changes
  1.845 Sun Aug 25 22:00:00 EST 2019
  * Croak if is_joinable, is_running, or join is called by a non-managed
    process in MCE::Child. Added LIMITATION section to the documentation.
  * Improved is_joinable, is_running, list_joinable, and list_running
    in MCE::Child. Thank you, Philippe Baumgart.
  * Added example (Consumer requests item) to MCE::Channel documentation.
  * Support the task_end option regardless if user_tasks is specified.
  * Support IO::All::{ File, Pipe, STDIO } for input data including
    output via MCE->print($io, ...), printf, and say.
  * Support gather => MCE::Candy::out_iter_fh($io) using MCE::Candy.
* Thu Aug 15 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.844
  see /usr/share/doc/packages/perl-MCE/Changes
  1.844 Wed Aug 14 21:30:00 EST 2019
  * Resolved MCE stalling when specifying max_retries with init_relay.
    Ditto for loop_timeout with init_relay on UNIX platforms.
    Thank you, Chris Denley.
  * Enhanced loop_timeout to handle workers dieing uncontrollably from
    any user_tasks (i.e. task_id >= 0). Previously, only task_id == 0.
  * Improved IPC on the Windows platform for edge case when a worker is
    awaiting input while the manager process is restarting a worker.
  * MCE, MCE::Child workers exit immediately upon receiving a SIGSEGV signal.
    This safeguards IPC from stalling inside the manager process.
  * Enhanced the _wait_one private function in MCE::Child.
  * Removed Prima from the list for auto-enabling the posix_exit option.
    Prima (since 1.52) is parallel safe during global cleanup.
  * Reached 100%% Pod coverage.
* Wed Jul 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.843
  see /usr/share/doc/packages/perl-MCE/Changes
  1.843 Tue Jul 23 22:30:00 EST 2019
  * Updated results in MCE::Child (Parallel::ForkManager-like demonstration).
  * Completed missing interrupt signal-safety for the non-blocking methods
    in MCE::Channel::Mutex and MCE::Channel::Threads.
* Mon Jul 22 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.842
  see /usr/share/doc/packages/perl-MCE/Changes
  1.842 Sun Jul 21 19:00:00 EST 2019
  * Fixed race condition abnormalities in MCE::Child.
  * Added Parallel::ForkManager-like demonstration to MCE::Child.
* Tue Jul 16 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.841
  see /usr/share/doc/packages/perl-MCE/Changes
  1.841 Sun Jul 07 23:30:00 EST 2019
  * Disabled t/04_channel_threads testing on Unix platforms for Perl less than
    5.10.1. Basically, the MCE::Channel::Threads implementation is not supported
    on older Perls unless the OS vendor applied upstream patches (i.e. works on
    RedHat/CentOS 5.x running Perl 5.8.x).
  * Added LIMITATIONS section to MCE::Channel::Threads.
  1.840 Sun Jul 07 05:00:00 EST 2019
  * Update MCE::Channel POD documentation.
  1.839 Sun Jul 07 04:30:00 EST 2019
    [NEW FEATURES]
  * Added MCE::Mutex::Channel2 providing two locks using a single channel.
    The secondary lock is accessible by calling methods with the '2' suffix.
    E.g. primary mutex ->lock, ->unlock; secondary mutex ->lock2, ->unlock2
  * Added MCE::Channel providing queue-like and two-way communication
    supporting threads and processes.
  * Added MCE::Child and compatibility with Perl 5.8. MCE::Child is based on
    MCE::Hobo, but using MCE::Channel for data retrieval without involving
    a shared-manager process.
  * Added MCE::Channel examples { channel1.pl and channel2.pl } using
    threads and MCE::Child respectively.
    https://github.com/marioroy/mce-examples/tree/master/chameneos
    [ENHANCEMENTS]
  * IPC update; removed unnecessary overhead including private methods
    _sysseek and _syswrite from MCE::Util (no longer needed).
  * Improved MCE->do, now callable by workers and the manager process.
  * Updated MCE::{ Flow, Grep, Loop, Map, Step, and Stream } documentation
    on passing an array reference versus a list for deeply input data.
  * Updated and re-organized the top-level MCE documentation, particularly
    improved clarity for the 'MCE Models' section.
  * Removed MANIFEST.SKIP.
* Thu Jan 24 2019 Stephan Kulow <coolo@suse.com>
- updated to 1.838
  see /usr/share/doc/packages/perl-MCE/Changes
  1.838 Wed Jan 23 08:30:00 EST 2019
  * IPC update, raising reliability across multiple platforms.
  * Improved hack for the Windows platform for nested MCE sessions.
  * Added _sysread, _sysseek, _syswrite, and _nonblocking to MCE::Util.
  * Added barrier option to MCE::Queue: allows one to disable.
* Sun Aug 26 2018 coolo@suse.com
- updated to 1.837
  see /usr/share/doc/packages/perl-MCE/Changes
  1.837 Sat Aug 25 13:00:00 EST 2018
  * Seeds the Math::Random::MT::Auto generator automatically when present
    for non-threads, similarly to Math::Random and Math::Prime::Util, to
    avoid child processes sharing the same seed value as the parent and
    each other. The new seed is computed using the current seed.
* Tue Jun 26 2018 coolo@suse.com
- updated to 1.836
  see /usr/share/doc/packages/perl-MCE/Changes
  1.836 Mon Jun 25 08:30:00 EST 2018
  * Moved validation code from MCE::Util to MCE::Core::Validation.
  * Applied small optimizations.
* Wed Mar 14 2018 coolo@suse.com
- updated to 1.835
  see /usr/share/doc/packages/perl-MCE/Changes
  1.835 Tue Mar 13 15:00:00 EST 2018
  * Added gather and relay demonstrations to MCE::Relay.
  * Load IO::Handle for extra stability, preventing workers loading uniquely.
  * Load Net::HTTP and Net::HTTPS before spawning if present LWP::UserAgent.
    See http://www.perlmonks.org/?node_id=1199760
    and http://www.perlmonks.org/?node_id=1199891.
* Wed Feb  7 2018 coolo@suse.com
- updated to 1.834
  see /usr/share/doc/packages/perl-MCE/Changes
  1.834 Tue Jan 23 08:00:00 EST 2018
  * Improved Queue await and dequeue performance on the Windows platform.
  * Added chameneos-redux parallel demonstrations on Github:
    https://github.com/marioroy/mce-examples/tree/master/chameneos
* Fri Dec 29 2017 coolo@suse.com
- updated to 1.833
  see /usr/share/doc/packages/perl-MCE/Changes
  1.833 Thu Dec 28 16:00:00 EST 2017
  * Fixed bug with sequence (#10), broken in 1.832. Thank you, @djerius.
* Wed Nov 22 2017 coolo@suse.com
- updated to 1.832
  see /usr/share/doc/packages/perl-MCE/Changes
  1.832 Tue Nov 21 15:30:00 EST 2017
  * Added LWP::UserAgent to list for enabling posix_exit.
  * Improved number-sequence generation for big integers.
  * Improved wantarray support in MCE::Mutex synchronize.
  * Removed limit check on chunk_size option.
* Tue Oct 10 2017 coolo@suse.com
- updated to 1.831
  see /usr/share/doc/packages/perl-MCE/Changes
  1.831 Sun Oct 08 20:30:00 EST 2017
  * Added STFL (Terminal UI) to list for enabling posix_exit.
    See http://www.perlmonks.org/?node_id=1200923.
  * Math::Prime::Util random numbers now unique between MCE workers.
    See http://www.perlmonks.org/?node_id=1200960.
* Thu Sep 14 2017 coolo@suse.com
- updated to 1.830
  see /usr/share/doc/packages/perl-MCE/Changes
  1.830 Tue Sep 12 17:00:00 EST 2017
    [BUG FIXES]
  * Fixed MCE and MCE::Relay stalling when setting the input record separator.
    See http://www.perlmonks.org/?node_id=1196701. Thank you, JediWombat.
  * Fixed bug with dequeue_nb in MCE::Queue (#8). Thank you, @bokutin.
  * Fixed signal handler (#9). Thank you, @chrisdenley.
    [ENHANCEMENTS]
  * Added Coro and Win32::GUI to list for enabling posix_exit.
  * Added support for Haiku to get_ncpu in MCE::Util.
  * Allow gathering to a shared array in MCE::Candy.
  * Improved CPU count on the AIX platform in MCE::Util.
  * Improved signal handling, including nested parallel-sessions.
  * Improved running MCE::Hobo inside MCE workers.
  * Improved running MCE with PDL.
  * Refactored logic for MCE->do, bi-directional callback feature.
  * Preserve lexical type for numbers during IPC: MCE->do and MCE::Queue.
  * No longer loads threads on the Windows platform in MCE::Signal.
    This enables MCE::Hobo 1.827 to spin faster, including lesser
    memory consumption. Threads isn't required to run MCE::Hobo.
  * Removed extra white-space from POD documentation.
  * Validated MCE on SmartOS.
* Thu May  4 2017 coolo@suse.com
- updated to 1.829
  see /usr/share/doc/packages/perl-MCE/Changes
  1.829 Wed May 03 03:00:00 EST 2017
  * Reduced memory consumption.
* Sat Apr 29 2017 coolo@suse.com
- updated to 1.828
  see /usr/share/doc/packages/perl-MCE/Changes
  1.828 Fri Apr 28 16:00:00 EST 2017
    [BUG FIXES]
  * Do not enable barrier mode for Queue on the Windows platform.
  * Fixed MCE::Mutex::Flock, tmp_file missing script name in path.
    [ENHANCEMENTS]
  * Added Curses and Prima to list for enabling the posix_exit option.
  * Allow a hash as input_data: Core API, MCE::{ Flow, Loop, Step }.
  * Improved API documentation on MCE models with more synopsis.
  * Enhanced IPC and signal handling. Reduced memory consumption.
  * Make tmp_dir on demand in MCE::Signal. Ditto for sess_dir in MCE.
  * Load Fcntl, File::Path, Symbol on demand.
* Fri Apr  7 2017 coolo@suse.com
- updated to 1.827
  see /usr/share/doc/packages/perl-MCE/Changes
  1.827 Wed Apr 05 01:30:00 EST 2017
  * Do not enable barrier mode in Queue if constructed inside a thread or
    by MCE Model (e.g. Step, Stream). Ditto for fast => 1 option.
  * Updated MCE to not croak when running Perl in taint mode via perl -T.
    Failing -T was MCE::Core::Input::{ Generator, Sequence }, MCE::Signal,
    and MCE::Util.
  * Added Denis Fateyev, Felipe Gasper, and Paul Howarth to Credits.
  1.826 Sun Apr 02 23:00:00 EST 2017
  * Is now safe running MCE with the Wx GUI toolkit (wxWidgets).
  1.825 Sun Apr 02 07:00:00 EST 2017
  * Updated MCE::Queue. The following provides a comparison for the
    enhancements made regarding IPC during 1.822 through 1.825, in order
    to run on machines having "many" cores. I ran with 12, 96, and 192
    workers on an 8 core box.
    A. MCE queue, dequeue 100k items.
    my $Q = MCE::Queue->new();
    $Q->enqueue( 1 .. 100000 );
    $Q->end();    MCE 1.608 $Q->enqueue((undef) x 12, 96, or 192);
    MCE->new(
    max_workers => 12, 96, or 192,
    user_func   => sub {
    while ( defined ( my $item = $Q->dequeue ) ) {
    ;
    }
    }
    )->run();
    MCE 1.608:  12 ~ 1.799 secs  96 ~ 8.702 secs  192 ~ 18.083 secs
    MCE 1.821:     ~ 1.450 secs     ~ 5.231 secs      ~  8.102 secs
    MCE 1.825:     ~ 0.976 secs     ~ 1.067 secs      ~  1.509 secs
    B. Input file containing 250k lines ( 300 MiB ).
    MCE->new(
    input_data  => "/dev/shm/file_250k.txt",
    max_workers => 12, 96, or 192,
    chunk_size  => 1,
    use_slurpio => 1,
    user_func   => sub { }
    )->run();
    MCE 1.608:  12 ~ 3.605 secs  96 ~ 8.074 secs  192 ~ 8.465 secs
    MCE 1.821:     ~ 3.613 secs     ~ 8.058 secs      ~ 8.607 secs
    MCE 1.825:     ~ 3.567 secs     ~ 2.601 secs      ~ 3.199 secs
    C. Sequence of numbers from 1 to 200k.
    MCE->new(
    sequence    => [ 1, 200000 ],
    max_workers => 12, 96, or 192,
    chunk_size  => 1,
    user_func   => sub { }
    )->run();
    MCE 1.608:  12 ~ 1.236 secs  96 ~ 2.922 secs  192 ~ 3.113 secs
    MCE 1.821:     ~ 1.227 secs     ~ 2.915 secs      ~ 3.106 secs
    MCE 1.825:     ~ 1.250 secs     ~ 1.203 secs      ~ 1.581 secs
  * Results were captured on a fast 8 core system running CentOS Linux 7.
    The thing to take from this is that running many workers "no longer"
    results in up to 5.6x penalty regarding IPC.
  1.824 Sat Apr 01 01:00:00 EST 2017
  * Completed validation for running MCE on a box having 100+ cores.
  * Tuned the number of data-channels for IPC. Set upper limit in
    MCE::Core::Input::{ Handle and Sequence } to not impact the
    OS kernel. The result is better performance, yet graceful.
* Sat Apr  1 2017 coolo@suse.com
- updated to 1.823
  see /usr/share/doc/packages/perl-MCE/Changes
  1.823 Fri Mar 31 19:30:00 EST 2017
  * Calibrated the number of data-channels for IPC.
  1.822 Fri Mar 31 11:00:00 EST 2017
  * Check for EINTR during sysread and syswrite.
  * Improved reliability when running nested MCE sessions.
  * Updated MCE::Mutex with Channel and Fcntl implementations.
  * Completed validation for using MCE with 200+ cores.
* Mon Mar 20 2017 coolo@suse.com
- updated to 1.821
  see /usr/share/doc/packages/perl-MCE/Changes
  1.821 Sun Mar 19 04:00:00 EST 2017
  * Improved reliability when running MCE with threads.
  * Added parallel Net::Pcap and Ping demonstrations on Github:
    https://github.com/marioroy/mce-examples/tree/master/network
  * Optimized 'dequeue' method in MCE::Queue.
  * Optimized 'synchronize' method in MCE::Mutex.
* Tue Mar 14 2017 coolo@suse.com
- updated to 1.820
  see /usr/share/doc/packages/perl-MCE/Changes
  1.820 Thu Mar 09 02:00:00 EST 2017
  * Improved reliability when running MCE inside an eval block.
* Tue Mar  7 2017 coolo@suse.com
- updated to 1.819
  see /usr/share/doc/packages/perl-MCE/Changes
  1.819 Fri Mar 03 23:00:00 EST 2017
  * Fixed issue with localizing AUTOFLUSH variable before autoflush handles.
    Thank you, Charles Hendry for raising the issue.
  1.818 Wed Mar 01 22:00:00 EST 2017
  * Updated bin/mce_grep for determining chunk level. Ditto for chunk size.
    Fixed an issue for not seeing STDERR output with '--chunk-level=file'.
    Added support for zgrep, zegrep, and zfgrep. Thank you, Jeff Rouse.
  * Changed Sereal to Sereal::Decoder and Sereal::Encoder in recommends
    section inside Makefile and META files.
  * Refactored MCE::Queue. Merged local and manager code base into one.
    Removed t/04_norm_que_local.t and t/04_prio_que_local.t.
  * Added 'end' method to MCE::Queue.
    Updated documentation on dequeue and pending.
* Wed Mar  1 2017 coolo@suse.com
- updated to 1.817
  see /usr/share/doc/packages/perl-MCE/Changes
  1.817 Sat Feb 25 02:00:00 EST 2017
  * Improved bin/mce_grep. When -r is specified and zero paths are given,
    start recursively in the current directory versus await data from STDIN.
    Set chunk-level accordingly to list mode.
  1.816 Fri Feb 24 19:00:00 EST 2017
  * Revised the description on max_retries in MCE::Core.pod.
  1.815 Fri Feb 24 01:00:00 EST 2017
  * Fixed divide-by-zero error in MCE->yield.
  * Refactored code for the interval option by moving the code to the manager
    process. This allows the manager process to accomodate the next available
    worker and ready to run. Previoulsy, a worker taking a long time resulted
    in empty time slots. Thank you, Philippe Baumgart for your patience.
  * Revised the description on posix_exit in MCE::Core.pod.
* Tue Feb 21 2017 coolo@suse.com
- updated to 1.814
  see /usr/share/doc/packages/perl-MCE/Changes
  1.814 Mon Feb 20 05:30:00 EST 2017
  * Enhanced the progress option for use with MCE->process.
    Updated progress demonstrations in MCE::Core.pod.
* Fri Feb 17 2017 coolo@suse.com
- updated to 1.813
  see /usr/share/doc/packages/perl-MCE/Changes
  1.813 Thu Feb 16 02:30:00 EST 2017
  * Last minute request by Philippe Baumgart (reminder and long overdue).
    Added progress option, a code block for receiving info on progress made.
    See MCE::Core.pod for demonstrations accommodating all input data types.
* Wed Feb 15 2017 coolo@suse.com
- updated to 1.812
  see /usr/share/doc/packages/perl-MCE/Changes
  1.812 Tue Feb 14 17:00:00 EST 2017
  * Bumped minimum requirement for Sereal to 3.015 when available.
    Added regression ensuring matching version for Encoder and Decoder.
  1.811 Mon Feb 13 23:30:00 EST 2017
  * Fixed bug in MCE::Queue (dequeue_nb) when queue has zero items.
  * Applied small optimization in MCE::Core::Input::Sequence and Generator.
  * Added cross-platform template to MCE::Examples for making an executable.
  * Removed signal handling for XCPU and XFSZ from MCE::Signal.
  * Imply posix_exit => 1 if Gearman::XS or Gearman::Util is present during
    MCE construction.
  * Added MCE + Gearman demonstrations (xs and non-xs) on Github:
    https://github.com/marioroy/mce-examples/tree/master/gearman_xs
    https://github.com/marioroy/mce-examples/tree/master/gearman
  * Changed kilobytes and megabytes to kibiBytes (KiB) and mebiBytes (MiB)
    respectively inside the documentation.
* Sun Dec 11 2016 coolo@suse.com
- updated to 1.810
  see /usr/share/doc/packages/perl-MCE/Changes
  1.810 Fri Dec 09 23:30:00 EST 2016
  * Updated check for IO handle allowed. This allows $gather_fh = *STDOUT{IO},
    construction in Perl <= 5.10.1. Thank you, Qiang Wang.
* Thu Nov 24 2016 coolo@suse.com
- updated to 1.809
  see /usr/share/doc/packages/perl-MCE/Changes
* Fri Nov 11 2016 coolo@suse.com
- updated to 1.808
  see /usr/share/doc/packages/perl-MCE/Changes
  1.808 Sat Nov 01 02:00:00 EST 2016
  * Workers persist unless shutdown explicity while running alongside
    the Mojolicious framework.
* Wed Nov  2 2016 coolo@suse.com
- updated to 1.807
  see /usr/share/doc/packages/perl-MCE/Changes
  1.807 Tue Nov 01 16:00:00 EST 2016
  * Enhanced relay capabilities. Added Mandelbrot example to MCE::Example.
    Added extra demonstrations to MCE::Relay. Also, added test script.
  * Tweaked manager-loop delay for special cases -- applies to MSWin32 only.
* Thu Oct 13 2016 coolo@suse.com
- updated to 1.806
  see /usr/share/doc/packages/perl-MCE/Changes
  1.806 Tue Oct 11 21:30:00 EST 2016
  * Fixed two typos. Thank you, Florian Schlichting.
  * Support input_data with nested arrays in MCE Models.
* Fri Sep  2 2016 coolo@suse.com
- updated to 1.805
  see /usr/share/doc/packages/perl-MCE/Changes
  1.805 Thu Sep 01 16:00:00 EST 2016
  * Fixed bug in MCE::Queue (#4). Thank you, Mary Ehlers.
  * Improved support for running MCE with Tk. Added Tk demonstrations to
    MCE::Examples. Thank you, Götz Meyer.
* Sat Jul 30 2016 coolo@suse.com
- updated to 1.804
  see /usr/share/doc/packages/perl-MCE/Changes
  1.804 Thu Jul 28 23:00:00 EST 2016
  * Removed the sleep statement in MCE->restart_worker.
  * Added FCGI::ProcManager demonstrations to MCE::Examples.
  * Automatically set posix_exit to 1 whenever (F)CGI.pm is present.
  * Thank you Kai Wasserbäch (TheRealCuran) for the cool test case.
    https://github.com/marioroy/mce-perl/issues/1
* Tue Jul 12 2016 coolo@suse.com
- updated to 1.803
  see /usr/share/doc/packages/perl-MCE/Changes
  1.803 Sun Jul 10 23:30:00 EST 2016
  * Re-enabled Sereal 3.008+ for Perl < v5.12.0, if available.
  * Optimized dequeue methods in MCE::Queue.
* Wed Jul  6 2016 coolo@suse.com
- updated to 1.802
  see /usr/share/doc/packages/perl-MCE/Changes
  1.802 Mon Jul 04 03:30:00 EST 2016
  * Default to Storable for serialization in Perl less than v5.12.0.
    Sereal 3.008+, if available, is loaded automatically in Perl v5.12+.
  1.801 Sun Jul 03 00:30:00 EST 2016
    [BUG FIXES]
  * Fixed race condition in Queue->await.
    [ENHANCEMENTS]
  * MCE 1.801 is stable on all supported platforms.
  * Completed work supporting cyclical include of MCE Core / Models.
  * Updated MCE to support Perl included with Git Bash.
  * Renamed temp dir from 'mce' to 'Perl-MCE' under user's %%TEMP%%
    location on Windows. E.g. Native Perl, Cygwin, Git Bash.
* Thu Jun 23 2016 coolo@suse.com
- updated to 1.800
  see /usr/share/doc/packages/perl-MCE/Changes
  1.800 Sat Jun 18 16:30:00 EST 2016
    [BUG FIXES]
  * Fixed dequeue (count) in MCE::Queue for standalone mode.
    [ENHANCEMENTS]
  * On Windows, improved stablity and feature parity with UNIX.
  * Use Sereal 3.008+ automatically if available on the box.
    [NEW FEATURES]
  * Added support for cyclical include of MCE Core, MCE Models, and
    MCE Queue by scoping the configuration to the local package.
    This resolves (RT#107384), bug reported by Kai Wasserbäch.
* Tue May 31 2016 coolo@suse.com
- updated to 1.708
  see /usr/share/doc/packages/perl-MCE/Changes
  1.708 Sat May 28 14:00:00 EST 2016
    [BUG FIXES]
  * Improved import routine in MCE Models and MCE::Subs. This resolves an
    issue where functions are not exported; e.g. mce_flow, mce_flow_s.
    [ENHANCEMENTS]
  * Added support for IO::TieCombine handles. This enables MCE->print and
    MCE->sendto to work reliably with App::Cmd and App::Cmd::Tester.
    See Testing and Capturing Output in MCE::Examples.
* Sat May 28 2016 coolo@suse.com
- updated to 1.707
  see /usr/share/doc/packages/perl-MCE/Changes
  1.707 Wed May 25 16:00:00 EST 2016
    [BUG FIXES]
  * Fixed logic when workers exit. Improved reliability on Windows.
    [ENHANCEMENTS]
  * Applied MCE-1.700-provides.patch from RedHat. Thank you, Paul Howarth.
  * Added META.json to the distribution.
* Thu May  5 2016 coolo@suse.com
- updated to 1.706
  see /usr/share/doc/packages/perl-MCE/Changes
  1.706 Fri Apr 22 21:30:00 EST 2016
    [ENHANCEMENTS]
  * Time::HiRes sleep resolution is 15 milliseconds on Windows and Cygwin.
    Adjusted timeout values accordingly. Thank you Daniel Dragan.
  * Reinstated the hack for faster IO when use_slurpio => 1 is specified.
    Tuned chunk_size => 'auto'.
  1.705 Thu Apr 14 10:00:00 EST 2016
  * Bumped version for Test::More to 0.88. Thank you Paul Howarth.
  1.704 Thu Apr 14 05:00:00 EST 2016
    [BUG FIXES]
  * Fixed restart on the Windows platform, bug introduced in 1.700.
  * Reached *stable* on all major platforms for MCE 1.7x.
    [ENHANCEMENTS]
  * Enabled auto-destroy for MCE objects.
  * Enabled freeze callbacks for Sereal.
  * Switched bug tracking to Github.
  * Tweaked test scripts.
* Wed Mar 23 2016 coolo@suse.com
- updated to 1.703
  see /usr/share/doc/packages/perl-MCE/Changes
  1.703 Sat Mar 19 23:00:00 EST 2016
  * Completed IPC optimizations for 1.7.
  1.702 Tue Mar 15 17:00:00 EST 2016
  * Bumped version.
  1.701 Tue Mar 15 12:00:00 EST 2016
    [ENHANCEMENTS]
  * Some folks have expressed a wish for running MCE 1.7 with Perl v5.8.
    To restore support for Perl v5.8, removed MCE::Shared and MCE::Hobo
    from the MCE 1.701 distribution.
  * MCE::Shared will be released after MCE 1.700 is deleted from CPAN.
    Thank you for your patience during this transition.
* Fri Mar 11 2016 coolo@suse.com
- updated to 1.700
  see /usr/share/doc/packages/perl-MCE/Changes
* Fri Apr 17 2015 coolo@suse.com
- initial package $version
  * created by $NAME $VERSION
